clear all; clc;

global h y_m tau A d

del_t=10; % timestep for integration
sim_time=15000; %total simulation time

A=2000; %area of Level tank
tau= input('process time delay (in seconds)  '); %measurement filter time constant

%% Initial condition
h(1)=1;
y_m(1)=1;
u=3*ones(1,sim_time/del_t);
d=3*ones(1,sim_time/del_t);

t = del_t:del_t:sim_time;  
step = t>=11000;
S_S=input('Step size for the change in out flow (-3 to 3) ');
u=u+step*S_S;

B=y_m(1);
C=u(1);
xa=[1];
plt = plot(xa,B,xa,C);
plt(1).YDataSource='B';
plt(2).YDataSource='C'; 
plt(1).XDataSource='xa';
plt(2).XDataSource='xa';


%% Integrate the model
for i=2:sim_time/del_t
        
    % Process update
    dh_dt=1/A*(d(i)-u(i));
    h(i)=h(i-1)+dh_dt*del_t;
    
    % Measurement Noise
    if i>tau/del_t
    y_m(i)=h(i-tau/del_t);
    else
        y_m(i)=y_m(1);
    end
    
    if y_m(i)>=2  %(the simulator stops when the tank is full)
        y_m(i)=2;
    end
    
    if y_m(i)<= 0 %(the simulator stops when the tank is full)
        y_m(i)=0;
    end
    
    if i>800
    B=y_m(i-800:i);
    C=u(i-800:i);
    xa=[1+i:1:801+i];
    refreshdata(plt,'caller');
    axis([1+i 801+i 0 6]);
    legend('Measured Level','Out flow');
    drawnow
    end
    
end

%% Plot the results
plot(y_m);
hold on
plot(u);
xlabel('Time');
ylabel('Level (m)');
legend('Measured Level','Outflow');
axis([0 sim_time/del_t 0 6]);




 